@@ -248,37 +248,6 @@ gdata_parser_int64_to_iso8601 (gint64 _time)
 	return g_time_val_to_iso8601 (&time_val);
 }
 
-gchar *
-gdata_parser_int64_to_iso8601_numeric_timezone (gint64 _time)
-{
-	GTimeVal time_val;
-	gchar *iso8601;
-	gchar **date_time_components;
-	gchar *retval;
-
-	time_val.tv_sec = _time;
-	time_val.tv_usec = 0;
-
-	iso8601 = g_time_val_to_iso8601 (&time_val);
-
-	/* FIXME: Work around for Google's incorrect ISO 8601 implementation.
-	 * They appear to not like dates in the format ‘2014-08-09T21:07:05Z’
-	 * which specify a timezone using ‘Z’ and no microseconds. This varies
-	 * between services.
-	 *
-	 * See: https://bugzilla.gnome.org/show_bug.cgi?id=732809
-	 * https://bugzilla.gnome.org/show_bug.cgi?id=780067
-	 * https://code.google.com/a/google.com/p/apps-api-issues/issues/detail?id=3595
-	 * http://stackoverflow.com/a/17630320/2931197 */
-	date_time_components = g_strsplit (iso8601, "Z", 2);
-	retval = g_strjoinv (".000001+00:00", date_time_components);
-	g_strfreev (date_time_components);
-
-	g_free (iso8601);
-
-	return retval;
-}
-
 gboolean
 gdata_parser_int64_from_iso8601 (const gchar *date, gint64 *_time)
 {
@@ -664,6 +633,9 @@ gdata_parser_object_from_element_setter (xmlNode *element, const gchar *element_
 {
 	GDataParsable *parsable, *parent_parsable;
 	GDataParserSetterFunc setter;
+	GError *local_error = NULL;
+
+	g_return_val_if_fail (!(options & P_REQUIRED) || !(options & P_IGNORE_ERROR), FALSE);
 
 	/* We're lax on the types so that we don't have to do loads of casting when calling the function, which makes the parsing code more legible */
 	setter = (GDataParserSetterFunc) _setter;
@@ -674,9 +646,20 @@ gdata_parser_object_from_element_setter (xmlNode *element, const gchar *element_
 		return FALSE;
 
 	/* Get the object and check for instantiation failure */
-	parsable = _gdata_parsable_new_from_xml_node (object_type, element->doc, element, NULL, error);
+	parsable = _gdata_parsable_new_from_xml_node (object_type, element->doc, element, NULL, &local_error);
+	g_assert ((parsable == NULL) == (local_error != NULL));
+
 	if (options & P_REQUIRED && parsable == NULL) {
 		/* The error has already been set by _gdata_parsable_new_from_xml_node() */
+		g_propagate_error (error, g_steal_pointer (&local_error));
+		*success = FALSE;
+		return TRUE;
+	} else if ((options & P_IGNORE_ERROR) && parsable == NULL) {
+		g_clear_error (&local_error);
+		*success = TRUE;
+		return TRUE;
+	} else if (local_error != NULL) {
+		g_propagate_error (error, g_steal_pointer (&local_error));
 		*success = FALSE;
 		return TRUE;
 	}
