@@ -99,6 +99,7 @@
 #include <glib/gi18n-lib.h>
 
 #include "gdata-documents-entry.h"
+#include "gdata-documents-entry-private.h"
 #include "gdata-parser.h"
 #include "gdata-types.h"
 #include "gdata-private.h"
@@ -814,7 +815,6 @@ parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GEr
 static gboolean
 post_parse_json (GDataParsable *parsable, gpointer user_data, GError **error)
 {
-	GDataDocumentsEntryPrivate *priv = GDATA_DOCUMENTS_ENTRY (parsable)->priv;
 	GDataLink *_link;
 	const gchar *id;
 	gchar *uri;
@@ -829,10 +829,6 @@ post_parse_json (GDataParsable *parsable, gpointer user_data, GError **error)
 	g_free (uri);
 	g_object_unref (_link);
 
-	/* Since the document-id is identical to GDataEntry:id, which is parsed by the parent class, we can't
-	 * create the resource-id while parsing. */
-	priv->resource_id = g_strconcat ("document:", id, NULL);
-
 	return TRUE;
 }
 
@@ -1042,6 +1038,21 @@ gdata_documents_entry_get_resource_id (GDataDocumentsEntry *self)
 	return self->priv->resource_id;
 }
 
+void
+_gdata_documents_entry_set_resource_id (GDataDocumentsEntry *self, const gchar *resource_id)
+{
+	g_return_if_fail (GDATA_IS_DOCUMENTS_ENTRY (self));
+	g_return_if_fail (resource_id != NULL && resource_id[0] != '\0');
+
+	if (g_strcmp0 (resource_id, self->priv->resource_id) == 0)
+		return;
+
+	g_free (self->priv->resource_id);
+	self->priv->resource_id = g_strdup (resource_id);
+
+	g_object_notify (G_OBJECT (self), "resource-id");
+}
+
 /**
  * gdata_documents_entry_set_writers_can_invite:
  * @self: a #GDataDocumentsEntry
